Coverage for pages.testproj.test_settings: 5%

# Coverage for pages.testproj.test_settings : 5%

## 66 statements 3 run 0 excluded 63 missing

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 | # -*- coding: utf-8 -*- # Django settings for cms project. import os PROJECT_DIR = os.path.dirname(__file__) DEBUG = True TEMPLATE_DEBUG = DEBUG ADMINS = ( # ('Your Name', 'your_email@domain.com'), ) CACHE_BACKEND = 'locmem:///' MANAGERS = ADMINS DATABASE_ENGINE = 'sqlite3' # 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' or 'oracle'. DATABASE_NAME = 'cms.db' # Or path to database file if using sqlite3. DATABASE_USER = '' # Not used with sqlite3. DATABASE_PASSWORD = '' # Not used with sqlite3. DATABASE_HOST = '' # Set to empty string for localhost. Not used with sqlite3. DATABASE_PORT = '' # Set to empty string for default. Not used with sqlite3. # Local time zone for this installation. Choices can be found here: # http://en.wikipedia.org/wiki/List_of_tz_zones_by_name # although not all choices may be avilable on all operating systems. # If running in a Windows environment this must be set to the same as your # system time zone. TIME_ZONE = 'America/Chicago' SITE_ID = 1 # If you set this to False, Django will make some optimizations so as not # to load the internationalization machinery. USE_I18N = True MEDIA_ROOT = STATIC_ROOT = os.path.join(PROJECT_DIR, 'media') MEDIA_URL = '/media/' STATIC_ROOT = os.path.join(PROJECT_DIR, 'media', 'static') STATIC_URL = MEDIA_URL + 'static/' # Absolute path to the directory that holds pages media. # PAGES_MEDIA_ROOT = os.path.join(STATIC_ROOT, 'pages', 'media', 'pages') # Absolute path to the directory that holds media. ADMIN_MEDIA_ROOT = os.path.join(STATIC_ROOT, 'admin_media') ADMIN_MEDIA_PREFIX = '/admin_media/' FIXTURE_DIRS = [os.path.join(PROJECT_DIR, 'fixtures')] # Make this unique, and don't share it with anybody. SECRET_KEY = '*xq7m@)*f2awoj!spa0(jibsrz9%c0d=e(g)v*!17y(vx0ue_3' # List of callables that know how to import templates from various sources. TEMPLATE_LOADERS = ( # this syntax is deprecated with django 1.2 'django.template.loaders.filesystem.load_template_source', 'django.template.loaders.app_directories.load_template_source', # could help 'django.template.loaders.eggs.load_template_source', ) TEMPLATE_CONTEXT_PROCESSORS = ( "django.core.context_processors.auth", "django.core.context_processors.i18n", "django.core.context_processors.debug", "django.core.context_processors.request", "django.core.context_processors.media", "pages.context_processors.media", #"staticfiles.context_processors.static_url", ) INTERNAL_IPS = ('127.0.0.1',) MIDDLEWARE_CLASSES = ( 'django.contrib.sessions.middleware.SessionMiddleware', 'django.middleware.locale.LocaleMiddleware', 'django.middleware.common.CommonMiddleware', 'django.contrib.auth.middleware.AuthenticationMiddleware', 'django.middleware.doc.XViewMiddleware', ) ROOT_URLCONF = 'pages.testproj.urls' TEMPLATE_DIRS = ( # Put strings here, like "/home/html/django_templates" or "C:/www/django/templates". # Always use forward slashes, even on Windows. # Don't forget to use absolute paths, not relative paths. os.path.join(PROJECT_DIR, 'templates'), ) CACHE_BACKEND = "locmem:///?timeout=300&max_entries=6000" INSTALLED_APPS = ( 'django.contrib.auth', 'django.contrib.contenttypes', 'django.contrib.sessions', 'django.contrib.admin', 'django.contrib.sites', 'pages.testproj.documents', 'tagging', 'pages', 'mptt', 'staticfiles', #'tinymce', # disabled to make "setup.py test" to work properly #'south', # these 2 package don't create any dependecies 'authority', # haystack change coverage score report by importing modules #'haystack', ) PAGE_TINYMCE = False PAGE_TAGGING = True PAGE_CONNECTED_MODELS = [{ 'model':'pages.testproj.documents.models.Document', 'form':'pages.testproj.documents.models.DocumentForm', 'options':{ 'extra': 3, 'max_num': 10, }, },] # Default language code for this installation. All choices can be found here: # http://www.i18nguy.com/unicode/language-identifiers.html LANGUAGE_CODE = 'en-us' # This is defined here as a do-nothing function because we can't import # django.utils.translation -- that module depends on the settings. gettext_noop = lambda s: s # languages you want to translate into the CMS. PAGE_LANGUAGES = ( ('de', gettext_noop('German')), ('fr-ch', gettext_noop('Swiss french')), ('en-us', gettext_noop('US English')), ) # You should add here all language you want to accept as valid client # language. By default we copy the PAGE_LANGUAGES constant and add some other # similar languages. languages = list(PAGE_LANGUAGES) languages.append(('fr-fr', gettext_noop('French'))) languages.append(('fr-be', gettext_noop('Belgium french'))) LANGUAGES = languages # This enable you to map a language(s) to another one, these languages should # be in the LANGUAGES config def language_mapping(lang): if lang.startswith('fr'): # serve swiss french for everyone return 'fr-ch' return lang PAGE_LANGUAGE_MAPPING = language_mapping PAGE_DEFAULT_TEMPLATE = 'pages/examples/index.html' PAGE_TEMPLATES = ( ('pages/examples/nice.html', 'nice one'), ('pages/examples/cool.html', 'cool one'), ('pages/examples/editor.html', 'raw editor'), ) PAGE_SANITIZE_USER_INPUT = True PAGE_USE_SITE_ID = True HAYSTACK_SITECONF = 'example.search_sites' HAYSTACK_SEARCH_ENGINE = 'dummy' #HAYSTACK_WHOOSH_PATH = os.path.join(PROJECT_DIR, 'whoosh_index') COVERAGE_EXCLUDE_MODULES = ( "pages.migrations.*", "pages.tests.*", "pages.urls", "pages.__init__", "pages.search_indexes", ) COVERAGE_HTML_REPORT = True COVERAGE_BRANCH_COVERAGE = False TEST_RUNNER = 'example.test_runner.run_tests' #here = os.path.abspath(os.path.dirname(__file__)) #NOSE_ARGS = [os.path.join(here, os.pardir, "pages", "tests"), # "--cover3-package=pages", # "--cover3-branch", # "--with-coverage3", # "--cover3-html", # "--cover3-exclude=%s" % ",".join(COVERAGE_EXCLUDE_MODULES)] try: import test_extensions except ImportError: pass else: INSTALLED_APPS += ("test_extensions", ) try: from local_settings import * except ImportError: pass